@@ -24,7 +24,6 @@ module Network.HTTP.Types.Header
 , hContentMD5
 , hContentRange
 , hContentType
-, hCookie
 , hDate
 , hETag
 , hExpect
@@ -39,6 +38,7 @@ module Network.HTTP.Types.Header
 , hLastModified
 , hLocation
 , hMaxForwards
+, hOrigin
 , hPragma
 , hProxyAuthenticate
 , hProxyAuthorization
@@ -55,6 +55,10 @@ module Network.HTTP.Types.Header
 , hVia
 , hWWWAuthenticate
 , hWarning
+, hContentDisposition
+, hMIMEVersion
+, hCookie
+, hSetCookie
   -- ** Byte ranges
 , ByteRange(..)
 , renderByteRangeBuilder
@@ -70,10 +74,10 @@ import           Data.List
 #if __GLASGOW_HASKELL__ < 710
 import           Data.Monoid
 #endif
-import qualified Blaze.ByteString.Builder       as Blaze
-import qualified Blaze.ByteString.Builder.Char8 as Blaze
 import qualified Data.ByteString                as B
 import qualified Data.ByteString.Char8          as B8
+import qualified Data.ByteString.Builder        as B
+import qualified Data.ByteString.Lazy           as BL
 import qualified Data.CaseInsensitive           as CI
 import           Data.ByteString.Char8          () {-IsString-}
 import           Data.Typeable                  (Typeable)
@@ -91,9 +95,8 @@ type RequestHeaders = [Header]
 -- | Response Headers
 type ResponseHeaders = [Header]
 
--- | HTTP Header names
--- According to http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html
-hAccept, hAcceptCharset, hAcceptEncoding, hAcceptLanguage, hAcceptRanges, hAge, hAllow, hAuthorization, hCacheControl, hConnection, hContentEncoding, hContentLanguage, hContentLength, hContentLocation, hContentMD5, hContentRange, hContentType, hCookie, hDate, hETag, hExpect, hExpires, hFrom, hHost, hIfMatch, hIfModifiedSince, hIfNoneMatch, hIfRange, hIfUnmodifiedSince, hLastModified, hLocation, hMaxForwards, hPragma, hProxyAuthenticate, hProxyAuthorization, hRange, hReferer, hRetryAfter, hServer, hTE, hTrailer, hTransferEncoding, hUpgrade, hUserAgent, hVary, hVia, hWWWAuthenticate, hWarning :: HeaderName
+-- | HTTP Header names according to http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html
+hAccept, hAcceptCharset, hAcceptEncoding, hAcceptLanguage, hAcceptRanges, hAge, hAllow, hAuthorization, hCacheControl, hConnection, hContentEncoding, hContentLanguage, hContentLength, hContentLocation, hContentMD5, hContentRange, hContentType, hDate, hETag, hExpect, hExpires, hFrom, hHost, hIfMatch, hIfModifiedSince, hIfNoneMatch, hIfRange, hIfUnmodifiedSince, hLastModified, hLocation, hMaxForwards, hPragma, hProxyAuthenticate, hProxyAuthorization, hRange, hReferer, hRetryAfter, hServer, hTE, hTrailer, hTransferEncoding, hUpgrade, hUserAgent, hVary, hVia, hWWWAuthenticate, hWarning :: HeaderName
 hAccept             = "Accept"
 hAcceptCharset      = "Accept-Charset"
 hAcceptEncoding     = "Accept-Encoding"
@@ -111,7 +114,6 @@ hContentLocation    = "Content-Location"
 hContentMD5         = "Content-MD5"
 hContentRange       = "Content-Range"
 hContentType        = "Content-Type"
-hCookie             = "Cookie"
 hDate               = "Date"
 hETag               = "ETag"
 hExpect             = "Expect"
@@ -143,6 +145,20 @@ hVia                = "Via"
 hWWWAuthenticate    = "WWW-Authenticate"
 hWarning            = "Warning"
 
+-- | HTTP Header names according to http://www.w3.org/Protocols/rfc2616/rfc2616-sec19.html
+hContentDisposition, hMIMEVersion :: HeaderName
+hContentDisposition = "Content-Disposition"
+hMIMEVersion        = "MIME-Version"
+
+-- | HTTP Header names according to https://tools.ietf.org/html/rfc6265#section-4
+hCookie, hSetCookie :: HeaderName
+hCookie             = "Cookie"
+hSetCookie          = "Set-Cookie"
+
+-- | HTTP Header names according to https://tools.ietf.org/html/rfc6454
+hOrigin :: HeaderName
+hOrigin = "Origin"
+
 -- | RFC 2616 Byte range (individual).
 --
 -- Negative indices are not allowed!
@@ -152,23 +168,23 @@ data ByteRange
   | ByteRangeSuffix !Integer
   deriving (Show, Eq, Ord, Typeable, Data)
 
-renderByteRangeBuilder :: ByteRange -> Blaze.Builder
-renderByteRangeBuilder (ByteRangeFrom from) = Blaze.fromShow from `mappend` Blaze.fromChar '-'
-renderByteRangeBuilder (ByteRangeFromTo from to) = Blaze.fromShow from `mappend` Blaze.fromChar '-' `mappend` Blaze.fromShow to
-renderByteRangeBuilder (ByteRangeSuffix suffix) = Blaze.fromChar '-' `mappend` Blaze.fromShow suffix
+renderByteRangeBuilder :: ByteRange -> B.Builder
+renderByteRangeBuilder (ByteRangeFrom from) = B.integerDec from `mappend` B.char7 '-'
+renderByteRangeBuilder (ByteRangeFromTo from to) = B.integerDec from `mappend` B.char7 '-' `mappend` B.integerDec to
+renderByteRangeBuilder (ByteRangeSuffix suffix) = B.char7 '-' `mappend` B.integerDec suffix
 
 renderByteRange :: ByteRange -> B.ByteString
-renderByteRange = Blaze.toByteString . renderByteRangeBuilder
+renderByteRange = BL.toStrict . B.toLazyByteString . renderByteRangeBuilder
 
 -- | RFC 2616 Byte ranges (set).
 type ByteRanges = [ByteRange]
 
-renderByteRangesBuilder :: ByteRanges -> Blaze.Builder
-renderByteRangesBuilder xs = Blaze.copyByteString "bytes=" `mappend` 
-                             mconcat (intersperse (Blaze.fromChar ',') (map renderByteRangeBuilder xs))
+renderByteRangesBuilder :: ByteRanges -> B.Builder
+renderByteRangesBuilder xs = B.byteString "bytes=" `mappend`
+                             mconcat (intersperse (B.char7 ',') (map renderByteRangeBuilder xs))
 
 renderByteRanges :: ByteRanges -> B.ByteString
-renderByteRanges = Blaze.toByteString . renderByteRangesBuilder
+renderByteRanges = BL.toStrict . B.toLazyByteString . renderByteRangesBuilder
 
 -- | Parse the value of a Range header into a 'ByteRanges'.
 --
